Cortez Masto leads Laxalt in U.S. Senate race - YouTube
Description: Enjoy the videos and music you love, upload original content, and share it all with friends, family, and the world on YouTube.
Keywords: video, sharing, camera phone, video phone, free, upload

#

•

###

###

NaN / NaN
Back
Sign in

###

Home
Shorts
Subscriptions

###

Library
History
Sign in to like videos, comment, and subscribe.
Sign in

### Explore

Trending
Music
Movies & Shows
Live
Gaming
News
Sports
Learning
Fashion & Beauty

###

Browse channels

### More from YouTube

YouTube Premium
YouTube Music
YouTube Kids
YouTube TV

###

Settings
Report history
Help
Send feedback
Home
Home
Shorts
Shorts
Subscriptions
Subscriptions
Library
Library
History
History
All Live Gaming Music Quarterbacks Sketch comedy Tools NBA Podcasts Game shows Background music History Scene Characters Fish Eating Action-adventure games Science Cars Pop Music Recently uploaded
10:23 Now playing

### Actual Creepy Videos

penguinz0
penguinz0
Verified
•
6.8M views 6 months ago
6:28 Now playing

### Tom Cruise schools the cocky new generation of pilots | Top Gun 2 | CLIP

Boxoffice Movie Scenes
Boxoffice Movie Scenes
Verified
•
2.1M views 6 days ago
14:14 Now playing

### I Bought Everything In 5 Stores

MrBeast
MrBeast
Verified
•
92M views 1 year ago
15:08 Now playing

### Trying to Survive in Prison as a First Time Offender

PowerfulJRE
PowerfulJRE
Verified
•
11M views 4 months ago
41:27 Now playing

### The Oakland, California Homeless Problem is Beyond Belief

Nick Johnson
Nick Johnson
Verified
•
9.4M views 9 months ago
Now playing

### lofi hip hop radio - beats to relax/study to

Lofi Girl
Lofi Girl
Verified
•
23K watching
LIVE
10:07 Now playing

### Proof Your Life Is A LIE

SSSniperWolf
SSSniperWolf
Verified
•
19M views 1 year ago
34:59 Now playing

### What Happens If You Put A Giant Propeller On A Bike?

Fireball Tool
Fireball Tool
•
9.5M views 4 months ago

##
Shorts

### Toddler Gives Dog a Hug Before Going to School | Shorts

•
2.6M views

### Tom Holland STOPS Interview To Watch Zendaya's Arrival #shorts

•
39M views

### Pink Venom challenge by Itzy Ryujin #shorts #pinkvenomchallenge #blackpink

•
1.4M views

### Mom rolls window down on daughter in front of guys

•
43M views

### His friends told him it was a trampoline ?

•
6.5M views

### Puppy Drums #shorts

•
24M views

### Millie Bobby Brown Evolution [2022-2014] #shorts

•
548K views

### People VS. Cartoons Ep. 7

•
71M views
14:53 Now playing

### Best Trick Plays of the 2021 College Football Season

PSC Highlights
PSC Highlights
•
577K views 4 months ago
Now playing

### Calming music for nerves?healing music for the heart and blood vessels,relaxation,music for the soul

Soothing Your Soul
Soothing Your Soul
Verified
•
1.6K watching
LIVE
15:56 Now playing

### A Medical Look Into What Killed Every President

Doctor Mike
Doctor Mike
Verified
•
1.5M views 5 days ago
39:13 Now playing

### Hunting Nepal’s Mad Honey That Makes You Hallucinate - HONEY HUNTERS

Yes Theory
Yes Theory
Verified
•
6.1M views 2 months ago

##
Trending

36:28 Now playing

### Our Best Metal Detecting Find Yet! PLUS...A Road Update

Ghost Town Living
Ghost Town Living
Verified
•
411K views 2 days ago
21:26 Now playing

### Is Linus Tech Tips Screwdriver Best? LTT vs Wera, Snap On, PB Swiss, Milwaukee, MegaPro, GearWrench

Project Farm
Project Farm
Verified
•
761K views 1 day ago
12:54 Now playing

### Uncle Roger LOVE INSANE EGG FRIED RICE TECHNIQUE (ft. Adam Liaw)

mrnigelng
mrnigelng
Verified
•
2M views 1 day ago
33:15 Now playing

### Pokemon but if something can go wrong, it does.

SmallAnt
SmallAnt
Verified
•
919K views 1 day ago
19:30 Now playing

### I Built the Ultimate Cyberpunk PC

Nerdforge
Nerdforge
Verified
•
524K views 1 day ago
2:35 Now playing

### NBA YoungBoy - Purge Me

YoungBoy Never Broke Again
YoungBoy Never Broke Again
Official Artist Channel
•
1.3M views 20 hours ago
5:43 Now playing

### Taylor Hawkins Forever - Nandi Bushell - Playing Wembley with Foo Fighters - Learn to Fly - Age 12

Nandi Bushell
Nandi Bushell
Verified
•
455K views 1 day ago
1:16 Now playing

### Season 1 Episode 4 Preview | House of the Dragon (HBO)

GameofThrones
GameofThrones
Verified
•
1.4M views 21 hours ago
18:58 Now playing

###
TV Theories S1 E1
Film Theory: Someone PLEASE Help Elmo! (Sesame Street)

The Film Theorists
The Film Theorists
Verified
•
1.8M views 1 day ago
4:11 Now playing

### Pick a Video Game Item

Ice Cream Sandwich
Ice Cream Sandwich
Verified
•
567K views 1 day ago
5:30 Now playing

### BabyTron - Prince of The Mitten 2 (Official Video)

BabyTron SB
BabyTron SB
Official Artist Channel
•
247K views 1 day ago
6:59 Now playing

### Race Highlights | 2022 Dutch Grand Prix

FORMULA 1
FORMULA 1
Verified
•
4.6M views 1 day ago
10:32:36 Now playing

### CCR, Scorpions, GNR, Bon Jovi, U2, Led Zeppelin, Aerosmith ?? Rock Ballads 70's 80's 90's

Music In Paradise
Music In Paradise
Verified
•
9M views Streamed 1 year ago
10:36 Now playing

### "I Googled the Definition of a Feminist" - Dave Chappelle

Comedy
Comedy
•
3.6M views 4 weeks ago
6:18 Now playing

### Foo Fighters ft. Shane Hawkins Perform "My Hero" | MTV

MTV
MTV
Verified
•
3M views 1 day ago
Fundraiser
10:42 Now playing

### AMAZING HIDDEN GATES AND ROOMS THAT YOU HAVEN'T SEEN BEFORE

TechZone
TechZone
Verified
•
5.6M views 2 months ago
Featured
This week’s biggest hits!
YouTube Music’s "The Hit List" playlist brings you the biggest hits from today’s top artists
Listen now
2:20:12 Now playing

### Dark Academia Classical Music

HALIDONMUSIC
HALIDONMUSIC
Verified
•
401K views 4 months ago
10:58 Now playing

### I Finally Watched She-Hulk

penguinz0
penguinz0
Verified
•
2.8M views 2 days ago
25:57 Now playing

### Luke Davidson Facts Tik Tok Compilation 2022 - TikTok Craft

TikTok Craft
TikTok Craft
•
3.7M views 5 months ago
28:07 Now playing

### Pawn Stars: 5 SUPER HIGH PRICE APPRAISALS (Big Offers WAY Over Asking)

Pawn Stars
Pawn Stars
Verified
•
32M views 8 months ago

###

•
OMF NV SEN Adam Laxalt #2 15B
If playback doesn't begin shortly, try restarting your device.
You're signed out
Videos you watch may be added to the TV's watch history and influence TV recommendations. To avoid this, cancel and sign in to YouTube on your computer.
Ad ·
0:14
Why this ad?
5
Share
Include playlist
An error occurred while retrieving sharing information. Please try again later.
0:00
0:15
0:01 / 0:15•Watch full video

# Cortez Masto leads Laxalt in U.S. Senate race

534 views534 views
Jul 13, 2022
8 News NOW Las Vegas
8 News NOW Las Vegas
196K subscribers
Subscribe
The U.S. Senate election battle between Democrat Catherine Cortez Masto and Republican challenger Adam Laxalt will likely go down to the wire.
Show less Show more

## Description

The U.S. Senate election battle between Democrat Catherine Cortez Masto and Republican challenger Adam Laxalt will likely go down to the wire.
Show less Show more

## Comments 5

## Transcript

###

###

NaN / NaN
18:03 Now playing

### WEB EXTRA: Senate Candidate Adam Laxalt

8 News NOW Las Vegas
8 News NOW Las Vegas
•
838 views 1 year ago
55:44 Now playing

### U.S. Senate candidates Catherine Cortez-Masto and Joe Heck debate

8 News NOW Las Vegas
8 News NOW Las Vegas
•
10K views 5 years ago
1:28 Now playing

### Striking nursing home workers rally ahead of Labor Day parade

WTAE-TV Pittsburgh
WTAE-TV Pittsburgh
•
85 views 7 hours ago
New
4:47 Now playing

### Wisconsin race could decide Senate balance l ABCNL

ABC News
ABC News
•
21K views 3 weeks ago
3:12 Now playing

### How a Latina took a seat in the Senate in times of Trump: Catherine Cortez Masto

Univision Noticias
Univision Noticias
•
5.6K views 5 years ago
2:17 Now playing

### Emerson Poll takes a closer look at NV Senate race

8 News NOW Las Vegas
8 News NOW Las Vegas
•
1.9K views 1 month ago
2:36 Now playing

### Senator Catherine Cortez Masto Takes Oath of Office

Senator Catherine Cortez Masto
Senator Catherine Cortez Masto
•
1.2K views 5 years ago
3:37 Now playing

### Senators Heinrich, Cortez Masto, and Harris on Importance of Protecting Our National Monuments

U.S. Senator Martin Heinrich
U.S. Senator Martin Heinrich
•
503 views 5 years ago
3:11 Now playing

### These battleground states could flip the Senate in 2022

ABC News
ABC News
•
6.1K views 1 month ago
2:58 Now playing

### Winners in the top races in Tuesday's primary election

8 News NOW Las Vegas
8 News NOW Las Vegas
•
33K views 2 months ago
3:05 Now playing

### Young Voters Look To Play Key Roles In Georgia Senate Race | NBC News NOW

NBC News
NBC News
•
89K views 1 year ago
4:49 Now playing

### Dean Heller concedes to Jacky Rosen

8 News NOW Las Vegas
8 News NOW Las Vegas
•
5.7K views 3 years ago
6:15 Now playing

### Local Matters: Polling shows New Hampshire 2022 Senate race could be tight

CBS News
CBS News
•
7.4K views 10 months ago
1:44 Now playing

### Emerson College election polling

8 News NOW Las Vegas
8 News NOW Las Vegas
•
239 views 1 month ago
6:40 Now playing

### Cortez Masto Slams Mnuchin Over His Inability to Answer Basic Questions About National Debt

Senator Catherine Cortez Masto
Senator Catherine Cortez Masto
•
118K views 3 years ago
13:58 Now playing

### The Saudi prince: how dangerous is MBS?

The Economist
The Economist
•
2.8M views 10 days ago
4:19 Now playing

### Former Nevada Attorney General and Trump ally announces run for U.S. Senate in crucial race

CBS News
CBS News
•
3.6K views 1 year ago
9:23 Now playing

### Why Latino Voters’ Political Shifts Could Decide 2022’s Key Races | WSJ

Wall Street Journal
Wall Street Journal
•
204K views 3 months ago
6:14 Now playing

### Cortez Masto calls out oil and gas companies for putting profits over consumers

Senator Catherine Cortez Masto
Senator Catherine Cortez Masto
•
468 views 5 months ago
12:35 Now playing

### Lawrence: Sen. Graham Lied Because He’s ‘Afraid’ Of His Own Words

MSNBC
MSNBC
•
1.7M views 5 days ago
New
Show more
Showing results for cortez masto vs laxalt Search instead for cortez masto vs lazalt
0:38 Now playing

### Cortez Masto leads Laxalt in U.S. Senate race

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
534 views 1 month ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
The U.S. Senate election battle between Democrat Catherine Cortez Masto and Republican challenger Adam Laxalt will likely go ... The U.S. Senate election battle between Democrat Catherine Cortez Masto and Republican challenger Adam Laxalt will likely go ...
From the video description
SHORTS Now playing

### 'Mitch McConnell's Hand-Picked Candidate': Catherine Cortez Masto Responds To Adam Laxalt Campaign

Forbes Breaking News
Forbes Breaking News
Verified
•
7.3K views 1 year ago
Forbes Breaking News
Forbes Breaking News
Verified
In a message released to social media, Sen. Catherine Cortez Masto (D-NV) responded to the campaign announcement of former ... In a message released to social media, Sen. Catherine Cortez Masto (D-NV) responded to the campaign announcement of former ...
From the video description
1:09 Now playing

### Cortez Masto, Laxalt offer differing opinions on Supreme Court abortion ruling

KTNV Channel 13 Las Vegas
KTNV Channel 13 Las Vegas
Verified
•
378 views 2 months ago
KTNV Channel 13 Las Vegas
KTNV Channel 13 Las Vegas
Verified
Nevada Senator Catherine Cortez Masto and Republican Senate candidate Adam Laxalt both shared their thoughts on today's ... Nevada Senator Catherine Cortez Masto and Republican Senate candidate Adam Laxalt both shared their thoughts on today's ...
From the video description
CC
0:24 Now playing

### Laxalt files to run in US Senate challenge to Cortez Masto

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
288 views 1 year ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
Laxalt files to run in US Senate challenge to Cortez Masto. Laxalt files to run in US Senate challenge to Cortez Masto.
From the video description
2:17 Now playing

### Emerson Poll takes a closer look at NV Senate race

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
1.9K views 1 month ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
The race getting the most financial and advertising attention is for Senate. Democrat Catherine Cortez Masto is trying to hold onto ... The race getting the most financial and advertising attention is for Senate. Democrat Catherine Cortez Masto is trying to hold onto ...
From the video description
4:19 Now playing

### Former Nevada Attorney General and Trump ally announces run for U.S. Senate in crucial race

CBS News
CBS News
Verified
•
3.6K views 1 year ago
CBS News
CBS News
Verified
Adam Laxalt, Nevada's former attorney general and close ally of former President Donald Trump, announced his run for U.S. ... Adam Laxalt, Nevada's former attorney general and close ally of former President Donald Trump, announced his run for U.S. ...
From the video description
CC
1:31 Now playing

### Adam Laxalt y Catherine Cortez Masto ganan las primarias | Noticias Telemundo

Noticias Telemundo
Noticias Telemundo
Verified
•
2.6K views 2 months ago
Noticias Telemundo
Noticias Telemundo
Verified
Video oficial de Noticias Telemundo. Luego de conocer su victoria, Cortez Masto dijo que su contrincante fue un fiscal corrupto ... Video oficial de Noticias Telemundo. Luego de conocer su victoria, Cortez Masto dijo que su contrincante fue un fiscal corrupto ...
From the video description
CC
8:29 Now playing

### 2022 Nevada Senate Prediction | Cortez Masto vs Laxalt

Election Predictions Official
Election Predictions Official
•
6.7K views 1 year ago
Election Predictions Official
Election Predictions Official
Democrats aren't anticipating a close senate race in Nevada next year, but the Republican party firmly believes that the state is ... Democrats aren't anticipating a close senate race in Nevada next year, but the Republican party firmly believes that the state is ...
From the video description
EP PREDICTION | AMERICA'S CHOICE 2022 | EP RACE UPDATE | EP PROJECTION | EP OFFICIAL
5 auto-generated moments in this video
5 moments

##

#### EP PREDICTION

0:03

#### AMERICA'S CHOICE 2022

0:07

#### EP RACE UPDATE

0:51

#### EP PROJECTION

7:20

#### EP OFFICIAL

8:15
0:57 Now playing

### 'We did not need to be locked down,' Laxalt slams Democrats over pandemic, Biden agenda

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
681 views 10 months ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
During a weekend news conference, Republican U.S. Senate candidate Adam Laxalt slammed Democratic Sen. Catherine Cortez ... During a weekend news conference, Republican U.S. Senate candidate Adam Laxalt slammed Democratic Sen. Catherine Cortez ...
From the video description
0:18 Now playing

### Republican Adam Laxalt running for Senate

KTNV Channel 13 Las Vegas
KTNV Channel 13 Las Vegas
Verified
•
1K views 1 year ago
KTNV Channel 13 Las Vegas
KTNV Channel 13 Las Vegas
Verified
Former Nevada Attorney General Adam Laxalt has filed to run for Senate against Sen. Catherine Cortez Masto. Former Nevada Attorney General Adam Laxalt has filed to run for Senate against Sen. Catherine Cortez Masto.
From the video description
CC
1:59 Now playing

### CNN: Cortez Masto on Codifying Roe v. Wade

Catherine Cortez Masto
Catherine Cortez Masto
Verified
•
137 views 3 months ago
Catherine Cortez Masto
Catherine Cortez Masto
Verified
2:58 Now playing

### Winners in the top races in Tuesday's primary election

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
33K views 2 months ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
Republican Adam Laxalt wins his primary race against Sam Brown and will go up against incumbent Democratic U.S. Sen. Republican Adam Laxalt wins his primary race against Sam Brown and will go up against incumbent Democratic U.S. Sen.
From the video description

## People also watched

6:23 Now playing

### Election expert predicts who will win control of Congress

CNN
CNN
Verified
•
395K views 2 weeks ago
CNN
CNN
Verified
Political scientist Larry Sabato discusses who will win control of Congress after the midterm elections this Fall and why candidates ... Political scientist Larry Sabato discusses who will win control of Congress after the midterm elections this Fall and why candidates ...
From the video description
CC
9:46 Now playing

### Trump's Shadow Looms Over Midterm Primaries

MSNBC
MSNBC
Verified
•
362K views 1 month ago
MSNBC
MSNBC
Verified
NBC News' Steve Kornacki joins Morning Joe to break down the key Senate races to watch. » Subscribe to MSNBC: ... NBC News' Steve Kornacki joins Morning Joe to break down the key Senate races to watch. » Subscribe to MSNBC: ...
From the video description
CC
3:44 Now playing

### Manhasset vs Mt. Sinai | 2021 Long Island Class C Championship

LAXdotCOMtv
LAXdotCOMtv
•
14K views 1 year ago
LAXdotCOMtv
LAXdotCOMtv
It was a meeting between two of the very best on Long Island when Mt. Sinai took on Manhasset for the Long island Class C ... It was a meeting between two of the very best on Long Island when Mt. Sinai took on Manhasset for the Long island Class C ...
From the video description
4K
5:22 Now playing

### 20 Female Senators Sworn in on Capitol Hill

ABC News
ABC News
Verified
•
72K views 9 years ago
ABC News
ABC News
Verified
Diane Sawyer interviews the women of the new Congress. Diane Sawyer interviews the women of the new Congress.
From the video description
+3 more
2:21 Now playing

### WATCH: Nevada Sen. Catherine Cortez Masto’s full speech at the 2020 Democratic National Convention

PBS NewsHour
PBS NewsHour
Verified
•
7.7K views 2 years ago
PBS NewsHour
PBS NewsHour
Verified
Catherine Cortez Masto addressed Democrats on Aug. 17 during the first night of the Democratic National Convention. Kasich ran ... Catherine Cortez Masto addressed Democrats on Aug. 17 during the first night of the Democratic National Convention. Kasich ran ...
From the video description
8:29 Now playing

### Sen. Cortez Masto: 'I Don't Believe' There Is A Wedge In NV Dem. Party | Hallie Jackson | MSNBC

MSNBC
MSNBC
Verified
•
13K views 1 year ago
MSNBC
MSNBC
Verified
Senator Catherine Cortez Masto (D-NV) joins Hallie Jackson to discuss Democrats' attempts to reform the filibuster. Cortez Masto ... Senator Catherine Cortez Masto (D-NV) joins Hallie Jackson to discuss Democrats' attempts to reform the filibuster. Cortez Masto ...
From the video description
CC
0:48 Now playing

### Senator Cortez-Masto campaigns with teamsters

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
366 views 1 month ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
campaigning in Las Vegas. campaigning in Las Vegas.
From the video description
4:29 Now playing

### Catherine Cortez Masto: The first LatinaÂ senatorÂ in history

CNN
CNN
Verified
•
10K views 5 years ago
CNN
CNN
Verified
Sen. Catherine Cortez Masto is still learning her way around the halls of Congress but has already become an important symbol ... Sen. Catherine Cortez Masto is still learning her way around the halls of Congress but has already become an important symbol ...
From the video description
Who is Catherine Cortez Masto?
1 auto-generated moments in this video
1 moments

##

#### Who is Catherine Cortez Masto?

0:10
4:05 Now playing

### Sam Brown Attacks Laxalt Endorsements, Criticizes ‘Political Celebrities’

NBC News
NBC News
Verified
•
5.8K views 2 months ago
NBC News
NBC News
Verified
In an interview with NBC News Correspondent Guad Venegas, Nevada GOP primary candidate Sam Brown that his opponent, ... In an interview with NBC News Correspondent Guad Venegas, Nevada GOP primary candidate Sam Brown that his opponent, ...
From the video description
CC
18:03 Now playing

### WEB EXTRA: Senate Candidate Adam Laxalt

8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
•
838 views 1 year ago
8 News NOW Las Vegas
8 News NOW Las Vegas
Verified
WEB EXTRA: Senate Candidate Adam Laxalt. WEB EXTRA: Senate Candidate Adam Laxalt.
From the video description
SHORTS Now playing

### Senator Cortez Masto’s Freedom to Travel for Health Care Act

Senate Democrats
Senate Democrats
Verified
•
108 views 1 month ago
Senate Democrats
Senate Democrats
Verified
Today, Senate Democrats came to the floor to pass Senator Cortez Masto's Freedom to Travel for Health Care Act— to protect ... Today, Senate Democrats came to the floor to pass Senator Cortez Masto's Freedom to Travel for Health Care Act— to protect ...
From the video description
13:54 Now playing

### Protest of Adam Laxalt for representing Big Oil

Las Vegas Review-Journal
Las Vegas Review-Journal
•
657 views Streamed 2 months ago
Las Vegas Review-Journal
Las Vegas Review-Journal
Nevada workers gather at the Nevada State AFL-CIO to call out Adam Laxalt for getting rich at a Washington, D.C. firm that ... Nevada workers gather at the Nevada State AFL-CIO to call out Adam Laxalt for getting rich at a Washington, D.C. firm that ...
From the video description